@@ -37,6 +37,10 @@ impl Column {
             ColumnType::SmallInteger(_) => "i16".to_owned(),
             ColumnType::Integer(_) => "i32".to_owned(),
             ColumnType::BigInteger(_) => "i64".to_owned(),
+            ColumnType::TinyUnsigned(_) => "u8".to_owned(),
+            ColumnType::SmallUnsigned(_) => "u16".to_owned(),
+            ColumnType::Unsigned(_) => "u32".to_owned(),
+            ColumnType::BigUnsigned(_) => "u64".to_owned(),
             ColumnType::Float(_) => "f32".to_owned(),
             ColumnType::Double(_) => "f64".to_owned(),
             ColumnType::Json | ColumnType::JsonBinary => "Json".to_owned(),
@@ -90,6 +94,10 @@ impl Column {
             ColumnType::SmallInteger(_) => quote! { ColumnType::SmallInteger.def() },
             ColumnType::Integer(_) => quote! { ColumnType::Integer.def() },
             ColumnType::BigInteger(_) => quote! { ColumnType::BigInteger.def() },
+            ColumnType::TinyUnsigned(_) => quote! { ColumnType::TinyUnsigned.def() },
+            ColumnType::SmallUnsigned(_) => quote! { ColumnType::SmallUnsigned.def() },
+            ColumnType::Unsigned(_) => quote! { ColumnType::Unsigned.def() },
+            ColumnType::BigUnsigned(_) => quote! { ColumnType::BigUnsigned.def() },
             ColumnType::Float(_) => quote! { ColumnType::Float.def() },
             ColumnType::Double(_) => quote! { ColumnType::Double.def() },
             ColumnType::Decimal(s) => match s {
@@ -116,6 +124,10 @@ impl Column {
                 let s = s.to_string();
                 quote! { ColumnType::Custom(#s.to_owned()).def() }
             }
+            ColumnType::Enum(enum_name, _) => {
+                let enum_ident = format_ident!("{}", enum_name.to_camel_case());
+                quote! { #enum_ident::db_type() }
+            }
             #[allow(unreachable_patterns)]
             _ => unimplemented!(),
         };
@@ -194,9 +206,13 @@ mod tests {
                 ColumnType::Custom(SeaRc::new(Alias::new("cus_col")))
             ),
             make_col!("CakeId", ColumnType::TinyInteger(None)),
+            make_col!("CakeId", ColumnType::TinyUnsigned(Some(9))),
             make_col!("CakeId", ColumnType::SmallInteger(None)),
-            make_col!("CakeId", ColumnType::Integer(Some(11))),
+            make_col!("CakeId", ColumnType::SmallUnsigned(Some(10))),
+            make_col!("CakeId", ColumnType::Integer(None)),
+            make_col!("CakeId", ColumnType::Unsigned(Some(11))),
             make_col!("CakeFillingId", ColumnType::BigInteger(None)),
+            make_col!("CakeFillingId", ColumnType::BigUnsigned(Some(12))),
             make_col!("cake-filling-id", ColumnType::Float(None)),
             make_col!("CAKE_FILLING_ID", ColumnType::Double(None)),
             make_col!("CAKE-FILLING-ID", ColumnType::Binary(None)),
@@ -218,6 +234,10 @@ mod tests {
             "cake_id",
             "cake_id",
             "cake_id",
+            "cake_id",
+            "cake_id",
+            "cake_id",
+            "cake_filling_id",
             "cake_filling_id",
             "cake_filling_id",
             "cake_filling_id",
@@ -243,6 +263,10 @@ mod tests {
             "CakeId",
             "CakeId",
             "CakeId",
+            "CakeId",
+            "CakeId",
+            "CakeId",
+            "CakeFillingId",
             "CakeFillingId",
             "CakeFillingId",
             "CakeFillingId",
@@ -266,9 +290,13 @@ mod tests {
             "String",
             "String",
             "i8",
+            "u8",
             "i16",
+            "u16",
             "i32",
+            "u32",
             "i64",
+            "u64",
             "f32",
             "f64",
             "Vec<u8>",
@@ -300,9 +328,13 @@ mod tests {
             "ColumnType::String(Some(255u32)).def()",
             "ColumnType::Custom(\"cus_col\".to_owned()).def()",
             "ColumnType::TinyInteger.def()",
+            "ColumnType::TinyUnsigned.def()",
             "ColumnType::SmallInteger.def()",
+            "ColumnType::SmallUnsigned.def()",
             "ColumnType::Integer.def()",
+            "ColumnType::Unsigned.def()",
             "ColumnType::BigInteger.def()",
+            "ColumnType::BigUnsigned.def()",
             "ColumnType::Float.def()",
             "ColumnType::Double.def()",
             "ColumnType::Binary.def()",
